@@ -1,12 +1,17 @@
+mod app;
+mod console;
 mod directory_patcher;
 mod file_patcher;
 mod query;
 mod replacer;
 mod settings;
-pub use settings::Settings;
 mod stats;
-pub use crate::replacer::{replace, Replacement};
+
+pub use app::run;
+pub use console::{Console, Verbosity};
 pub use directory_patcher::DirectoryPatcher;
 pub use file_patcher::FilePatcher;
 pub use query::Query;
+pub use replacer::{replace, Replacement};
+pub use settings::Settings;
 pub use stats::Stats;
