@@ -1,5 +1,5 @@
 use crate::query::Query;
-use colored::*;
+
 use regex::Regex;
 
 /// Execute a query on a line of input.
@@ -50,72 +50,21 @@ impl<'a> Replacement<'a> {
 
     /// Return the input string
     pub fn input(&self) -> &str {
-        &self.output
+        self.input
     }
 
     pub(crate) fn num_fragments(&self) -> usize {
         self.fragments.len()
     }
 
-    /// Print the replacement as two lines (red then green)
-    /// ```
-    /// use ruplacer::{Query, replace};
-    /// let input = "let foo_bar = FooBar::new();";
-    /// let query = Query::subvert("foo_bar", "spam_eggs");
-    /// let replacement = replace(input, &query).unwrap();
-    /// replacement.print_self("foo.rs:3");
-    /// // outputs:
-    /// // foo.rs:3 let foo_bar = FooBar::new()
-    /// // foo.rs:3 let spam_eggs = SpamEggs::new()
-    /// ```
-    pub fn print_self(&self, prefix: &str) {
-        let red_underline = { |x: &str| x.red().underline() };
-        let input_fragments = self.fragments.into_iter().map(|x| &x.0);
-        let red_prefix = format!("{}{}", prefix, "- ".red());
-        Self::print_fragments(&red_prefix, red_underline, self.input, input_fragments);
-
-        let green_underline = { |x: &str| x.green().underline() };
-        let green_prefix = format!("{}{}", prefix, "+ ".green());
-        let output_fragments = self.fragments.into_iter().map(|x| &x.1);
-        Self::print_fragments(
-            &green_prefix,
-            green_underline,
-            &self.output,
-            output_fragments,
-        );
-    }
-
-    fn print_fragments<'f, C>(
-        prefix: &str,
-        color: C,
-        line: &str,
-        fragments: impl Iterator<Item = &'f Fragment>,
-    ) where
-        C: Fn(&str) -> ColoredString,
-    {
-        print!("{}", prefix);
-        let mut current_index = 0;
-        for (i, fragment) in fragments.enumerate() {
-            let Fragment { index, text } = fragment;
-            // Whitespace between prefix and the first fragment does not matter
-            if i == 0 {
-                print!("{}", &line[current_index..*index].trim_start());
-            } else {
-                print!("{}", &line[current_index..*index]);
-            }
-            print!("{}", color(text));
-            current_index = index + text.len();
-        }
-        print!("{}", &line[current_index..]);
-        if !line.ends_with('\n') {
-            println!()
-        }
+    pub(crate) fn fragments(&self) -> &Fragments {
+        &self.fragments
     }
 }
 
 // A list of input_fragment, output_fragment
 #[derive(Debug)]
-struct Fragments(Vec<(Fragment, Fragment)>);
+pub(crate) struct Fragments(Vec<(Fragment, Fragment)>);
 
 impl Fragments {
     fn new() -> Self {
@@ -161,9 +110,9 @@ impl<'a> IntoIterator for &'a Fragments {
 /// Represent a fragment of text, similar to the data structure returned
 /// by String::match_indices
 #[derive(Debug)]
-struct Fragment {
-    index: usize,
-    text: String,
+pub(crate) struct Fragment {
+    pub(crate) index: usize,
+    pub(crate) text: String,
 }
 
 trait Replacer {
@@ -271,15 +220,15 @@ impl<'a> Replacer for RegexReplacer<'a> {
 fn get_fragments(input: &str, query: &Query) -> Fragments {
     match query {
         Query::Substring(pattern, replacement) => {
-            let finder = SubstringReplacer::new(&pattern, &replacement);
+            let finder = SubstringReplacer::new(pattern, replacement);
             get_fragments_with_finder(input, finder)
         }
         Query::Regex(regex, replacement) => {
-            let finder = RegexReplacer::new(&regex, &replacement);
+            let finder = RegexReplacer::new(regex, replacement);
             get_fragments_with_finder(input, finder)
         }
         Query::Subvert(items) => {
-            let finder = SubvertReplacer::new(&items);
+            let finder = SubvertReplacer::new(items);
             get_fragments_with_finder(input, finder)
         }
     }
@@ -325,7 +274,7 @@ fn get_output(input: &str, fragments: &Fragments) -> String {
         } = output_fragment;
 
         output.push_str(&input[current_index..*input_index]);
-        output.push_str(&output_text);
+        output.push_str(output_text);
         current_index = input_index + input_text.len();
     }
     output.push_str(&input[current_index..]);
@@ -335,6 +284,8 @@ fn get_output(input: &str, fragments: &Fragments) -> String {
 #[cfg(test)]
 mod tests {
 
+    use crate::Console;
+
     use super::*;
     use regex::Regex;
 
@@ -370,7 +321,8 @@ mod tests {
         let replacement = "new";
         let query = Query::substring(pattern, replacement);
         let replacement = replace(input, &query).unwrap();
-        replacement.print_self("foo.txt:3 ");
+        let console = Console::new();
+        console.print_replacement("foo.txt:3 ", &replacement);
     }
 
     #[test]
